@@ -6,6 +6,12 @@ package UvT::Kiki::ACL::Config;
 
 use Xyzzy -self;
 
+use Xyzzy::Util qw(parse_time);
+
+field request_timeout => 3600;
+
+sub set_requesttimeout { $self->request_timeout(parse_time(shift)) }
+
 field allowed_users => {};
 
 sub set_allowedusers {
